#!/usr/bin/python

#
# Copyright (c) 2010 Nokia Corporation and/or its subsidiary(-ies).
# All rights reserved.
# This component and the accompanying materials are made available
# under the terms of "Eclipse Public License v1.0"
# which accompanies this distribution, and is available
# at the URL "http://www.eclipse.org/legal/epl-v10.html".
#
# Initial Contributors:
# Nokia Corporation - initial contribution.
#
# Contributors:
#
# Description:
# Blocks main module
#

import os
import logging
from optparse import OptionGroup

from Blocks.singleinstance import SingleInstance

from cmdlineapp import CmdlineApp
from blockscommand import BlocksCommand
import utils

class BlocksApp(CmdlineApp):
    ''' Blocks app '''

    def initParser(self):
        CmdlineApp.initParser(self)
        self.parser.add_option("-f", "--force", action="store_true",
            help="Force execution of a command and do not ask any confirmations")
        wsOptions = OptionGroup(self.parser, "Workspace selection")
        wsOptions.add_option("--wsid", type="int", help="Use workspace id")
        wsOptions.add_option("--wsname", help="Use workspace name")
        self.parser.add_option_group(wsOptions)

    def init(self):
        # Allow only one blocks instance per metadata-directory
        si = SingleInstance(utils.getMetaPath(), True)
        if si.alreadyRunning():
            print "Waiting for another instance of blocks to complete processing..."
        si.waitRelease()

        # Delete default variables and use BLOCKS variables instead
        for evar, blocks_evar in {"http_proxy": "BLOCKS_HTTP_PROXY",
                                  "ftp_proxy": "BLOCKS_FTP_PROXY",
                                  "no_proxy": "BLOCKS_NO_PROXY"}.iteritems():
            blocksvar = os.environ.get(blocks_evar)
            if blocksvar:
                logging.debug("Blocks variable %s found. Using it in place of %s. Value = %s", blocks_evar, evar, blocksvar)
                os.environ[evar] = blocksvar
            else:
                if evar in os.environ:
                    del os.environ[evar]
                    logging.debug("Environment variable %s deleted", evar)

def main():
    app = BlocksApp(BlocksCommand, "blocks", "blocks_info")
    app.run()

if __name__ == "__main__":
    main()