#
# Copyright (c) 2010 Nokia Corporation and/or its subsidiary(-ies).
# All rights reserved.
# This component and the accompanying materials are made available
# under the terms of "Eclipse Public License v1.0"
# which accompanies this distribution, and is available
# at the URL "http://www.eclipse.org/legal/epl-v10.html".
#
# Initial Contributors:
# Nokia Corporation - initial contribution.
#
# Contributors:
#
# Description:
# LocalBundle class capable of bundle installation
#

import logging
import urlparse
import utils
import tempfile
import shutil

class LocalBundle(object):
    ''' Install bundles from URIs '''
    def __init__(self, dpkg):
        self.dpkg = dpkg

    def install(self, uris):
        '''
        Install bundle(s) in uris list
        List must not be empty
        Raises ValueError if nothing to install
        '''
        assert uris, "uri installation list empty!"
        files = []
        tempdir = tempfile.mkdtemp(prefix="local-bundle")
        try:
            for uri in uris:
                # uri can be local filename without file scheme
                filename = uri
                if urlparse.urlparse(uri).scheme in ("http", "https", "ftp", "ftps", "file"):
                    downloadPath = tempfile.mktemp(dir=tempdir)
                    try:
                        utils.urlretrieve(uri, downloadPath)
                        filename = downloadPath
                    except IOError, ex:
                        if len(uris) == 1:
                            raise IOError(str(ex))
                        else:
                            logging.warning(str(ex))
                        filename = None
                if filename:
                    files.append(filename)
            if files:
                self.dpkg("--install %s" % utils.argsToStr(files))
            else:
                raise ValueError("Nothing to install")
        finally:
            shutil.rmtree(tempdir)